@@ -1,5 +1,5 @@
 from fastmcp import FastMCP
-from sirene import search_sirene_company
+from scripts.sirene import search_sirene_company
 import os
 import pynsee
 
